# Author : Oceane DELANDRE
# Date : 07-2023
# Language : R
# Description : Depth coverage figure chromosome by chromosome
# Publication : Delandre et al. Long-read sequencing and de novo genome assembly pipeline of two Plasmodium falciparum clones (Pf3D7, PfW2) using only the PromethION sequencer from Oxford Nanopore Technologies without whole genome amplification
# library import
library(ggplot2)
library(plyr)

# input coverage file (generate with "samtools depth")
COV <- read.table("coverage_3D7_consensus.txt")
colnames(COV) <- c("CHROM", "POS", "Depth")
COV$CHROM <- factor(COV$CHROM, levels = c("3D7_chromosome_1", "3D7_chromosome_2", "3D7_chromosome_3", "3D7_chromosome_4", "3D7_chromosome_5", "3D7_chromosome_6", "3D7_chromosome_7", "3D7_chromosome_8", "3D7_chromosome_9", "3D7_chromosome_10", "3D7_chromosome_11", "3D7_chromosome_12", "3D7_chromosome_13", "3D7_chromosome_14", "3D7_apicoplast", "3D7_mitochondria"), ordered = T)


#Average sequencing depth by chromosoms
ddply(COV, .(CHROM), summarise, Average_depth=mean(Depth), SD=sd(Depth))


p <- ggplot(data=COV, aes(x=POS, y=Depth))
p <- p + geom_line(aes(color=CHROM))
p <- p + facet_wrap(~ CHROM, scales = "free", nrow = 4, ncol = 4)
p <- p + theme_minimal() + theme(text = element_text(size=10))
p <- p + ylab(label="Sequencing depth") + xlab(label="Position on the genome")
p <- p + theme(legend.position = "none")
p

ggsave(filename = "3D7plot.png" , plot = p , width = 12 , height = 12 )

# End of script